Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS DeepRacer.

Actions, resources, and condition keys for AWS DeepRacer - Service Authorization Reference

# Actions, resources, and condition keys for AWS DeepRacer

AWS DeepRacer (service prefix: `deepracer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS DeepRacer
- Resource types defined by AWS DeepRacer
- Condition keys for AWS DeepRacer

## Actions defined by AWS DeepRacer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddLeaderboardAccessPermission [permission only] | Grants permission to add access for a private leaderboard | Write | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
AdminGetAccountConfig [permission only] | Grants permission to get current admin multiuser configuration for this account | Read |  |  |
AdminListAssociatedResources [permission only] | Grants permission to list all deepracer users with their associated resources created under this account | Read |  |  |
AdminListAssociatedUsers [permission only] | Grants permission to list user data for all users associated with this account | Read |  |  |
AdminManageUser [permission only] | Grants permission to manage a user associated with this account | Write |  |  |
AdminSetAccountConfig [permission only] | Grants permission to set configuration options for this account | Write |  |  |
CloneReinforcementLearningModel [permission only] | Grants permission to clone an existing DeepRacer model | Write | reinforcement_learning_model* |  |
track* |  |
| aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
CreateCar [permission only] | Grants permission to create a DeepRacer car in your garage | Write |  | aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
CreateLeaderboard [permission only] | Grants permission to create a leaderboard | Write |  | aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
CreateLeaderboardAccessToken [permission only] | Grants permission to create an access token for a private leaderboard | Write | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
CreateLeaderboardSubmission [permission only] | Grants permission to submit a DeepRacer model to be evaluated for leaderboards | Write | leaderboard* |  |
reinforcement_learning_model* |  |
| aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
CreateReinforcementLearningModel [permission only] | Grants permission to create ra einforcement learning model for DeepRacer | Write | track* |  |
| aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
DeleteLeaderboard [permission only] | Grants permission to delete a leaderboard | Write | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
DeleteModel [permission only] | Grants permission to delete a DeepRacer model | Write | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
EditLeaderboard [permission only] | Grants permission to edit a leaderboard | Write | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
GetAccountConfig [permission only] | Grants permission to get current multiuser configuration for this account | Read |  | deepracer:UserToken deepracer:MultiUser |
GetAlias [permission only] | Grants permission to retrieve the user's alias for submitting a DeepRacer model to leaderboards | Read |  | deepracer:UserToken deepracer:MultiUser |
GetAssetUrl [permission only] | Grants permission to download artifacts for an existing DeepRacer model | Read | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
GetCar [permission only] | Grants permission to retrieve a specific DeepRacer car from your garage | Read | car* |  |
| deepracer:UserToken deepracer:MultiUser |
GetCars [permission only] | Grants permission to view all the DeepRacer cars in your garage | Read |  | deepracer:UserToken deepracer:MultiUser |
GetEvaluation [permission only] | Grants permission to retrieve information about an existing DeepRacer model's evaluation jobs | Read | evaluation_job* |  |
| deepracer:UserToken deepracer:MultiUser |
GetLatestUserSubmission [permission only] | Grants permission to retrieve information about how the latest submitted DeepRacer model for a user performed on a leaderboard | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
GetLeaderboard [permission only] | Grants permission to retrieve information about leaderboards | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
GetModel [permission only] | Grants permission to retrieve information about an existing DeepRacer model | Read | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
GetPrivateLeaderboard [permission only] | Grants permission to retrieve information about private leaderboards | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
GetRankedUserSubmission [permission only] | Grants permission to retrieve information about the performance of a user's DeepRacer model that got placed on a leaderboard | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
GetTrack [permission only] | Grants permission to retrieve information about DeepRacer tracks | Read | track* |  |
GetTrainingJob [permission only] | Grants permission to retrieve information about an existing DeepRacer model's training job | Read | training_job* |  |
| deepracer:UserToken deepracer:MultiUser |
ImportModel [permission only] | Grants permission to import a reinforcement learning model for DeepRacer | Write |  | deepracer:UserToken deepracer:MultiUser |
ListEvaluations [permission only] | Grants permission to list a DeepRacer model's evaluation jobs | Read | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
ListLeaderboardEvaluations [permission only] | Grants permission to list all the user's leaderboard evaluation jobs for a leaderboard | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
ListLeaderboardSubmissions [permission only] | Grants permission to list all the DeepRacer model submissions of a user on a leaderboard | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
ListLeaderboards [permission only] | Grants permission to list all the available leaderboards | Read |  | deepracer:UserToken deepracer:MultiUser |
ListModels [permission only] | Grants permission to list all existing DeepRacer models | Read |  | deepracer:UserToken deepracer:MultiUser |
ListPrivateLeaderboardParticipants [permission only] | Grants permission to retrieve participant information about private leaderboards | Read | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
ListPrivateLeaderboards [permission only] | Grants permission to list all the available private leaderboards | Read |  | deepracer:UserToken deepracer:MultiUser |
ListSubscribedPrivateLeaderboards [permission only] | Grants permission to list all the subscribed private leaderboards | Read |  | deepracer:UserToken deepracer:MultiUser |
ListTagsForResource | Grants permission to lists tag for a resource | Read | car |  |
evaluation_job |  |
leaderboard |  |
leaderboard_evaluation_job |  |
reinforcement_learning_model |  |
training_job |  |
| aws:ResourceTag/${TagKey} deepracer:UserToken deepracer:MultiUser |
ListTracks [permission only] | Grants permission to list all DeepRacer tracks | Read |  |  |
ListTrainingJobs [permission only] | Grants permission to list a DeepRacer model's training jobs | Read | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
MigrateModels [permission only] | Grants permission to migrate previous reinforcement learning models for DeepRacer | Write |  |  |
PerformLeaderboardOperation [permission only] | Grants permission to performs the leaderboard operation mentioned in the operation attribute | Write | leaderboard |  |
| deepracer:UserToken deepracer:MultiUser |
RemoveLeaderboardAccessPermission [permission only] | Grants permission to remove access for a private leaderboard | Write | leaderboard* |  |
| deepracer:UserToken deepracer:MultiUser |
SetAlias [permission only] | Grants permission to set the user's alias for submitting a DeepRacer model to leaderboards | Write |  | deepracer:UserToken deepracer:MultiUser |
StartEvaluation [permission only] | Grants permission to evaluate a DeepRacer model in a simulated environment | Write | reinforcement_learning_model* |  |
track* |  |
| aws:RequestTag/${TagKey} aws:TagKeys deepracer:UserToken deepracer:MultiUser |
StopEvaluation [permission only] | Grants permission to stop DeepRacer model evaluations | Write | evaluation_job* |  |
| deepracer:UserToken deepracer:MultiUser |
StopTrainingReinforcementLearningModel [permission only] | Grants permission to stop training a DeepRacer model | Write | reinforcement_learning_model* |  |
| deepracer:UserToken deepracer:MultiUser |
TagResource | Grants permission to tag a resource | Tagging | car |  |
evaluation_job |  |
leaderboard |  |
leaderboard_evaluation_job |  |
reinforcement_learning_model |  |
training_job |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} deepracer:UserToken deepracer:MultiUser |
TestRewardFunction [permission only] | Grants permission to test reward functions for correctness | Write |  |  |
UntagResource | Grants permission to untag a resource | Tagging | car |  |
evaluation_job |  |
leaderboard |  |
leaderboard_evaluation_job |  |
reinforcement_learning_model |  |
training_job |  |
| aws:TagKeys deepracer:UserToken deepracer:MultiUser |
UpdateCar [permission only] | Grants permission to update a DeepRacer car in your garage | Write | car* |  |
| deepracer:UserToken deepracer:MultiUser |

## Resource types defined by AWS DeepRacer

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
car | `arn:$ { Partition}:deepracer:$ { Region}:$ { Account}:car/$ { ResourceId}` | aws:ResourceTag/${TagKey}
evaluation_job | `arn:$ { Partition}:deepracer:$ { Region}:$ { Account}:evaluation_job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
leaderboard | `arn:$ { Partition}:deepracer:$ { Region}::leaderboard/$ { ResourceId}` | aws:ResourceTag/${TagKey}
leaderboard_evaluation_job | `arn:$ { Partition}:deepracer:$ { Region}:$ { Account}:leaderboard_evaluation_job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
reinforcement_learning_model | `arn:$ { Partition}:deepracer:$ { Region}:$ { Account}:model/reinforcement_learning/$ { ResourceId}` | aws:ResourceTag/${TagKey}
track | `arn:$ { Partition}:deepracer:$ { Region}::track/$ { ResourceId}` |
training_job | `arn:$ { Partition}:deepracer:$ { Region}:$ { Account}:training_job/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS DeepRacer

AWS DeepRacer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions by tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions by tag keys in the request | ArrayOfString
deepracer:MultiUser | Filters access by multiuser flag | Bool
deepracer:UserToken | Filters access by user token in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.